@@ -41,8 +41,7 @@ public:
     virtual void add(WvStringParm id, WvMonikerCreateFunc *func);
     virtual void del(WvStringParm id);
     
-    virtual void *create(WvStringParm _s,
-			 IObject *obj = NULL, void *userdata = NULL);
+    virtual void *create(WvStringParm _s);
     
     // find a registry for objects of the given interface UUID
     static WvMonikerRegistry *find_reg(const UUID &iid);
