@@ -55,7 +55,16 @@ bool WvBufStream::isok() const
 }
 
 
-bool WvBufStream::pre_select(SelectInfo &si)
+void WvBufStream::pre_select(SelectInfo &si)
 {
-    return WvStream::pre_select(si) || si.wants.writable || eof;
+    WvStream::pre_select(si);
+
+    if (si.wants.writable || eof)
+	si.msec_timeout = 0;
+}
+
+
+bool WvBufStream::post_select(SelectInfo &si)
+{
+    return WvStream::post_select(si) || si.wants.writable || eof;
 }
