@@ -220,19 +220,22 @@ void WvFdStream::pre_select(SelectInfo &si)
 	    si.wants.readable, si.wants.writable, si.wants.isexception,
 	    si.inherit_request);
 #endif
-    if (isselectable(rfd))
+    if (si.wants.readable && (rfd >= 0))
     {
-	if (si.wants.readable && (rfd >= 0))
+	if (isselectable(rfd))
 	    FD_SET(rfd, &si.read);
+	else
+	    si.msec_timeout = 0; // not selectable -> *always* readable
     } 
     
     // FIXME: outbuf flushing should really be in WvStream::pre_select()
     // instead!  But it's hard to get the equivalent behaviour there.
-    if (isselectable(wfd))
+    if ((si.wants.writable || outbuf.used() || autoclose_time) && (wfd >= 0))
     {
-	if ((si.wants.writable || outbuf.used() || autoclose_time) 
-	      && (wfd >= 0))
+	if (isselectable(wfd))
 	    FD_SET(wfd, &si.write);
+	else
+	    si.msec_timeout = 0; // not selectable -> *always* writable
     }
     
     if (si.wants.isexception)
@@ -240,6 +243,7 @@ void WvFdStream::pre_select(SelectInfo &si)
 	if (rfd >= 0 && isselectable(rfd)) FD_SET(rfd, &si.except);
 	if (wfd >= 0 && isselectable(wfd)) FD_SET(wfd, &si.except);
     }
+    
     if (si.max_fd < rfd)
 	si.max_fd = rfd;
     if (si.max_fd < wfd)
@@ -263,10 +267,16 @@ bool WvFdStream::post_select(SelectInfo &si)
 	    return result;
     }
     
-    bool val = ((rfd >= 0 && FD_ISSET(rfd, &si.read)) ||
-	    (wfd >= 0 && FD_ISSET(wfd, &si.write)) ||
-	    (rfd >= 0 && FD_ISSET(rfd, &si.except)) ||
-	    (wfd >= 0 && FD_ISSET(wfd, &si.except)));
+    bool rforce = si.wants.readable && !isselectable(rfd),
+         wforce = si.wants.writable && !isselectable(wfd);
+    bool val = 
+	   (rfd >= 0 && (rforce || FD_ISSET(rfd, &si.read)))
+	|| (wfd >= 0 && (wforce || FD_ISSET(wfd, &si.write)))
+	|| (rfd >= 0 && (FD_ISSET(rfd, &si.except)))
+	|| (wfd >= 0 && (FD_ISSET(wfd, &si.except)));
+    
+    // fprintf(stderr, "fds_post_select: %d/%d %d/%d %d\n", 
+    //          rfd, wfd, rforce, wforce, val);
     
     if (val && si.wants.readable && read_requires_writable
       && read_requires_writable->isok()
