@@ -6,8 +6,12 @@
  */
 #include "uninullgen.h"
 #include "wvmoniker.h"
+#include "wvlinkerhack.h"
 
-static IUniConfGen *creator(WvStringParm, IObject *, void *)
+WV_LINK(UniNullGen);
+
+
+static IUniConfGen *creator(WvStringParm)
 {
     return new UniNullGen();
 }
