@@ -158,6 +158,9 @@ void WvConfigSectionEmu::Iter::rewind()
 WvLink *WvConfigSectionEmu::Iter::next()
 {
     while (iter.next())
+    {
+        // WvConf-enabled code expects all set keys to be non-empty;
+        // enforce this behaviour
 	if (!!iter->getme())
 	{
 	    /*
@@ -169,6 +172,7 @@ WvLink *WvConfigSectionEmu::Iter::next()
 	    assert(entry);
 	    return &link;
 	}
+    }
 
     return NULL;
 }
@@ -221,6 +225,7 @@ WvConfEmu::WvConfEmu(const UniConf &_uniconf)
     uniconf.add_callback(this,
 			 UniConfCallback(this, &WvConfEmu::notify),
 			 true);
+    dirty = false;
 }
 
 
@@ -256,6 +261,12 @@ void WvConfEmu::zap()
 }
 
 
+bool WvConfEmu::isclean() const
+{
+    return isok() && !dirty;
+}
+
+
 bool WvConfEmu::isok() const
 {
     return !uniconf.isnull();
@@ -291,6 +302,7 @@ void WvConfEmu::save()
 void WvConfEmu::flush()
 {
     uniconf.commit();
+    dirty = false;
 }
 
 
@@ -439,7 +451,7 @@ const char *WvConfEmu::fuzzy_get(WvStringList &sect, WvStringParm entry,
 {
     WvStringList::Iter i(sect);
     WvStringTable cache(5);
-    WvConfigSection *s;
+    WvConfigSectionEmu *s;
 
     for (i.rewind(); i.next(); )
     {
@@ -488,6 +500,7 @@ void WvConfEmu::set(WvStringParm section, WvStringParm entry,
             uniconf[section][entry].setme(value);
         else
             uniconf[section][entry].setme(WvString::null);
+        dirty = true;
     }
 }
 
@@ -511,6 +524,7 @@ void WvConfEmu::maybeset(WvStringParm section, WvStringParm entry,
 void WvConfEmu::delete_section(WvStringParm section)
 {
     uniconf[section].remove();
+    dirty = true;
 }
 
 
@@ -540,12 +554,15 @@ void WvConfEmu::Iter::rewind()
 
 WvLink *WvConfEmu::Iter::next()
 {
-    if (iter.next())
+    link.data = NULL;
+    while (link.data == NULL && iter.next())
     {
-	link.data = static_cast<void*>(conf[iter->key()]);
-	return &link;
+        link.data = static_cast<void*>(conf[iter->key()]);
+    }
+    if (link.data)
+    {
+        return &link;
     }
-
     return NULL;
 }
 
