@@ -17,19 +17,19 @@ static void pool_init()
     if (!pool)
     {
 	pool = new WvHttpPool;
-	WvIStreamList::globallist.append(pool, false);
+	WvIStreamList::globallist.append(pool, false, "pool_init urlpool");
     }
 }
 
 
-static IWvStream *creator(WvStringParm s, IObject *, void *)
+static IWvStream *creator(WvStringParm s)
 {
     pool_init();
     return pool->addurl(WvString("http:%s", s), "", false);
 }
 
 
-static IWvStream *screator(WvStringParm s, IObject *, void *)
+static IWvStream *screator(WvStringParm s)
 {
     pool_init();
     return pool->addurl(WvString("https:%s", s), "", false);
